@@ -198,7 +198,7 @@ AuxVarGen <- function(kappa, theta, likelihoodprev, rho0sum, CC, AreaMRW, W_dil,
 #' \emph{theta1} controls the shape of the interaction function and \emph{theta2} controls the shape of the interaction function and provides the location of the peak value.
 #'
 #' @references Park, J., Chang, W., & Choi, B. (2022). An interaction Neyman-Scott point process model for coronavirus disease-19. \emph{Spatial Statistics}, 47, 100561.
-#' @seealso \code{\link{print_outputs_internsp}}
+#' @seealso \code{\link{print.output_estinternsp}}
 #'
 #' @examples
 #' library(spatstat)
@@ -321,7 +321,8 @@ estinternsp <- function(X, control,
   CCC <- rpoispp(kappa, win = W_dil)
   CC <- t(rbind(CCC$x,CCC$y));CCdim[1] <- dim(CC)[1]
   integral <- KumulaVsech(CC, omega, x_left, x_right, y_bottom, y_top)
-  logP <- logpXCbeta(X,CC,alpha,omega,area(W),integral)
+  #logP <- logpXCbeta(X,CC,alpha,omega,area(W),integral)
+  logP <- logpXCbeta(X, CC, alpha, omega, AreaW, integral)
 
   # interaction loglikelihood
   CCdist <- rdist(CC)
@@ -430,6 +431,7 @@ estinternsp <- function(X, control,
              AlphaCI = AlphaCI, OmegaCI = OmegaCI, KappaCI = KappaCI, Theta1CI = Theta1CI, Theta2CI = Theta2CI,
              control = control, W_dil = W_dil,
              parameter = parameter)
+  class(res) <- c("output_estinternsp", class(res))
   return(res)
 }
 
@@ -440,7 +442,8 @@ estinternsp <- function(X, control,
 #'
 #' @description Output printing function of interaction neyman-scott process. It prints the estimated values and the posterior confidence intervals for each parameter.
 #'
-#' @param Output Output of the main function \code{\link{estinternsp}}.
+#' @param x Output of the main function \code{\link{estinternsp}}.
+#' @param ... further arguments passed from generic print function.
 #'
 #' @return Text output summarizing the posterior distributions for each parameter.
 #'
@@ -524,11 +527,12 @@ estinternsp <- function(X, control,
 #'                      x_left, x_right, y_bottom, y_top,
 #'                      W_dil,
 #'                      AreaW, AreaMRW, radius)
-#' print_outputs_internsp(Output)
+#' print(Output)
 #'
 #' @export
-
-print_outputs_internsp <- function(Output){
+print.output_estinternsp <- function(x, ...) {
+#print_outputs_internsp <- function(Output){
+  Output = x
 
   cat("Estimate of alpha (controls the expected number of occurrences or events around specified focal points or regions): ")
   cat(Output$Alphahat)
